==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiCGI/View/HTML/ImageUploadSuccess.pm <==
#
# WiKicker
#
#  ImageUploadSuccess.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: ImageUploadSuccess.pm,v 1.3 2004/05/01 07:06:08 naney Exp $
#
#

package WiKicker::WikiCGI::View::HTML::ImageUploadSuccess;

use 5.005;
use strict;

use WiKicker::WikiCGI::View::HTML;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::View::HTML);

sub make_html_body {
  my $self = shift;

  my $request = $self->request;

  my $query = $request->query;

  my $result;
  $result .= $query->h1('Upload OK');
  $result .= $query->p("img url is: " . $request->attribute('imageurl'));
  $result .= $query->img({src => $request->attribute('imageurl'), alt=>"Upload img"});
  $result .= $query->p(qq(Go back to <a href="/wiki">NaneyOrgWiki</a> and fix a picture in an page!));


  $self->response->add_content($result);
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiCGI/View/HTML/ImageUploadSuccess.pm <==
#
# WiKicker
#
#  ImageUploadSuccess.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: ImageUploadSuccess.pm,v 1.4 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::WikiCGI::View::HTML::ImageUploadSuccess;

use 5.005;
use strict;

use WiKicker::WikiCGI::View::HTML;

use vars qw(@ISA);
@ISA = qw(WiKicker::WikiCGI::View::HTML);

sub make_html_body {
  my $self = shift;

  my $request = $self->request;

  my $query = $request->query;

  my $result;
  $result .= $query->h1('Upload OK');
  $result .= $query->p('img url is: ' . $request->attribute('imageurl'));
  $result .= $query->img({src => $request->attribute('imageurl'), alt=>"Upload img"});
  $result .= $query->p(qq(Go back to <a href="/wiki">NaneyOrgWiki</a> and fix a picture in an page!));


  $self->response->add_content($result);
}

1;
